@@ -1,4 +1,5 @@
 #! -*- encoding: utf-8 -*-
+import subprocess
 import logging
 import os
 import sys
@@ -35,6 +36,22 @@ ALLOW_NO_GIT_SUBCOMMAND = ["login", "qa", "aggregator"]
 ALLOW_NO_HOME_SUBCOMMAND = ["login", "qa", "aggregator"]
 
 
+def upgrade_suite_py_if_needed(break_on_missing_package: bool = False) -> None:
+    """
+    Sometimes, when `suite-py` is launched with a virtual environment active, autoupgrade
+    cannot see the package as installed (as the command is used from the "global" user environment)
+    and raises an exception.
+    """
+    try:
+        # This checks that suite-py is available in the current environment
+        subprocess.run(["pip3", "show", "suite-py"], check=True)
+        # If available, upgrade (if needed)
+        Package("suite_py").upgrade()
+    except Exception as error:
+        if break_on_missing_package:
+            raise error
+
+
 @click.group()
 @click.option(
     "--project",
@@ -50,7 +67,7 @@ ALLOW_NO_HOME_SUBCOMMAND = ["login", "qa", "aggregator"]
 @click.option("-v", "--verbose", count=True)
 @click.pass_context
 def main(ctx, project, timeout, verbose):
-    Package("suite_py").upgrade()
+    upgrade_suite_py_if_needed(break_on_missing_package=False)
     print(f"v{__version__}")
 
     config = Config()
