@@ -1,20 +1,20 @@
-import sys
 import base64
 import hashlib
-import urllib
 import json
-import webbrowser
-import secrets
-import threading
 import logging
+import secrets
+import sys
+import threading
+import urllib
+import webbrowser
 from time import sleep
-import requests
 
-from flask import Flask, request, render_template
+import requests
+from flask import Flask, render_template, request
 from werkzeug.serving import make_server
-from suite_py.lib.handler.qainit_handler import QainitHandler as qainit
 
 from suite_py.lib import logger
+from suite_py.lib.handler.qainit_handler import QainitHandler as qainit
 
 ## Global vars for comunication between flask thread and main cli function
 received_callback = None
