@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 import sys
+
 import requests
 
 from suite_py.lib import logger
@@ -18,12 +19,10 @@ class ProjectLock:
             try:
                 req = self._captainhook.lock_project(self._project, self._env)
                 _handle_request(req)
-                logger.info(
-                    f"Bloccato deploy su {self._env} del progetto {self._project}"
-                )
+                logger.info(f"Locked deploy on {self._env} of {self._project} project")
             except requests.exceptions.Timeout:
                 logger.warning(
-                    "Richiesta a Captainhook in timeout. Prova con suite-py --timeout=60 lock-project lock"
+                    "Captainhook request timed out. Try with suite-py --timeout=60 lock-project lock"
                 )
                 sys.exit(1)
         elif self._action == "unlock":
@@ -31,22 +30,22 @@ class ProjectLock:
                 req = self._captainhook.unlock_project(self._project, self._env)
                 _handle_request(req)
                 logger.info(
-                    f"Abilitato deploy su {self._env} del progetto {self._project}"
+                    f"Unlocked deploy on {self._env} of {self._project} project"
                 )
             except requests.exceptions.Timeout:
                 logger.warning(
-                    "Richiesta a Captainhook in timeout. Prova con suite-py --timeout=60 lock-project unlock"
+                    "Captainhook request timed out. Try with suite-py --timeout=60 lock-project lock"
                 )
                 sys.exit(1)
         else:
-            logger.warning("Non ho capito che cosa devo fare")
+            logger.warning("I'm confused. Make the correct choice.")
             sys.exit(-1)
 
 
 def _handle_request(request):
     if request.status_code != 200:
         logger.error(
-            "Qualcosa è andato storto durante la richiesta. Richiedi supporto ai devops su slack."
+            "Something went wrong during the request. Request DevOps support on Slack."
         )
         sys.exit(-1)
 
